@@ -1,6 +1,15 @@
-__version__ = "1.9.0"
+__version__ = "1.10.0"
 
-from .data import SensorData, SensorDeviceInfo, SensorUpdate
+from .data import (
+    ATTR_HW_VERSION,
+    ATTR_MANUFACTURER,
+    ATTR_MODEL,
+    ATTR_NAME,
+    ATTR_SW_VERSION,
+    SensorData,
+    SensorDeviceInfo,
+    SensorUpdate,
+)
 from .description import SensorDescription
 from .device import DeviceKey
 from .device_class import DeviceClass
@@ -8,6 +17,11 @@ from .library import SensorLibrary
 from .value import SensorValue
 
 __all__ = [
+    "ATTR_HW_VERSION",
+    "ATTR_MANUFACTURER",
+    "ATTR_MODEL",
+    "ATTR_NAME",
+    "ATTR_SW_VERSION",
     "DeviceClass",
     "DeviceKey",
     "SensorData",
